| samplefa | R Documentation |
sample data read by function readDNAStringSet in R package 'Biostrings' from fasta format file, there are two target sequence resion in this data
data("samplefa")
Formal class 'DNAStringSet' [package "Biostrings"] with 5 slots
sample data read by function readDNAStringSet in R package 'Biostrings' from fasta format file, which is from ncbiRefSeq database for Homo Sapiens with referece genome version hg19
data(samplefa)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.